@@ -13,11 +13,11 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
-from .literals import DatasetTypeType, DomainType
+from .literals import DatasetTypeType, DomainType, OptimizationMetricType
 from .paginator import (
     ListDatasetGroupsPaginator,
     ListDatasetImportJobsPaginator,
@@ -75,7 +75,7 @@ __all__ = ("ForecastServiceClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -92,7 +92,7 @@ class Exceptions:
 
 class ForecastServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html)
     """
 
@@ -108,7 +108,7 @@ class ForecastServiceClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#can_paginate)
         """
 
@@ -119,14 +119,14 @@ class ForecastServiceClient(BaseClient):
         Domain: DomainType,
         DatasetType: DatasetTypeType,
         Schema: "SchemaTypeDef",
-        DataFrequency: str = None,
-        EncryptionConfig: "EncryptionConfigTypeDef" = None,
-        Tags: List["TagTypeDef"] = None
+        DataFrequency: str = ...,
+        EncryptionConfig: "EncryptionConfigTypeDef" = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateDatasetResponseTypeDef:
         """
         Creates an Amazon Forecast dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.create_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.create_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#create_dataset)
         """
 
@@ -135,13 +135,13 @@ class ForecastServiceClient(BaseClient):
         *,
         DatasetGroupName: str,
         Domain: DomainType,
-        DatasetArns: List[str] = None,
-        Tags: List["TagTypeDef"] = None
+        DatasetArns: Sequence[str] = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateDatasetGroupResponseTypeDef:
         """
         Creates a dataset group, which holds a collection of related datasets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.create_dataset_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.create_dataset_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#create_dataset_group)
         """
 
@@ -151,16 +151,16 @@ class ForecastServiceClient(BaseClient):
         DatasetImportJobName: str,
         DatasetArn: str,
         DataSource: "DataSourceTypeDef",
-        TimestampFormat: str = None,
-        TimeZone: str = None,
-        UseGeolocationForTimeZone: bool = None,
-        GeolocationFormat: str = None,
-        Tags: List["TagTypeDef"] = None
+        TimestampFormat: str = ...,
+        TimeZone: str = ...,
+        UseGeolocationForTimeZone: bool = ...,
+        GeolocationFormat: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateDatasetImportJobResponseTypeDef:
         """
         Imports your training data to an Amazon Forecast dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.create_dataset_import_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.create_dataset_import_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#create_dataset_import_job)
         """
 
@@ -169,14 +169,14 @@ class ForecastServiceClient(BaseClient):
         *,
         ForecastName: str,
         PredictorArn: str,
-        ForecastTypes: List[str] = None,
-        Tags: List["TagTypeDef"] = None
+        ForecastTypes: Sequence[str] = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateForecastResponseTypeDef:
         """
         Creates a forecast for each item in the `TARGET_TIME_SERIES` dataset that was
         used to train the predictor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.create_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.create_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#create_forecast)
         """
 
@@ -186,13 +186,13 @@ class ForecastServiceClient(BaseClient):
         ForecastExportJobName: str,
         ForecastArn: str,
         Destination: "DataDestinationTypeDef",
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateForecastExportJobResponseTypeDef:
         """
         Exports a forecast created by the  CreateForecast operation to your Amazon
         Simple Storage Service (Amazon S3) bucket.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.create_forecast_export_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.create_forecast_export_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#create_forecast_export_job)
         """
 
@@ -203,21 +203,22 @@ class ForecastServiceClient(BaseClient):
         ForecastHorizon: int,
         InputDataConfig: "InputDataConfigTypeDef",
         FeaturizationConfig: "FeaturizationConfigTypeDef",
-        AlgorithmArn: str = None,
-        ForecastTypes: List[str] = None,
-        PerformAutoML: bool = None,
-        AutoMLOverrideStrategy: Literal["LatencyOptimized"] = None,
-        PerformHPO: bool = None,
-        TrainingParameters: Dict[str, str] = None,
-        EvaluationParameters: "EvaluationParametersTypeDef" = None,
-        HPOConfig: "HyperParameterTuningJobConfigTypeDef" = None,
-        EncryptionConfig: "EncryptionConfigTypeDef" = None,
-        Tags: List["TagTypeDef"] = None
+        AlgorithmArn: str = ...,
+        ForecastTypes: Sequence[str] = ...,
+        PerformAutoML: bool = ...,
+        AutoMLOverrideStrategy: Literal["LatencyOptimized"] = ...,
+        PerformHPO: bool = ...,
+        TrainingParameters: Mapping[str, str] = ...,
+        EvaluationParameters: "EvaluationParametersTypeDef" = ...,
+        HPOConfig: "HyperParameterTuningJobConfigTypeDef" = ...,
+        EncryptionConfig: "EncryptionConfigTypeDef" = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        OptimizationMetric: OptimizationMetricType = ...
     ) -> CreatePredictorResponseTypeDef:
         """
         Creates an Amazon Forecast predictor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.create_predictor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.create_predictor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#create_predictor)
         """
 
@@ -227,13 +228,13 @@ class ForecastServiceClient(BaseClient):
         PredictorBacktestExportJobName: str,
         PredictorArn: str,
         Destination: "DataDestinationTypeDef",
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreatePredictorBacktestExportJobResponseTypeDef:
         """
         Exports backtest forecasts and accuracy metrics generated by the
         CreatePredictor operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.create_predictor_backtest_export_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.create_predictor_backtest_export_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#create_predictor_backtest_export_job)
         """
 
@@ -242,7 +243,7 @@ class ForecastServiceClient(BaseClient):
         Deletes an Amazon Forecast dataset that was created using the  CreateDataset
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.delete_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.delete_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_dataset)
         """
 
@@ -250,7 +251,7 @@ class ForecastServiceClient(BaseClient):
         """
         Deletes a dataset group created using the  CreateDatasetGroup operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.delete_dataset_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.delete_dataset_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_dataset_group)
         """
 
@@ -259,7 +260,7 @@ class ForecastServiceClient(BaseClient):
         Deletes a dataset import job created using the  CreateDatasetImportJob
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.delete_dataset_import_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.delete_dataset_import_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_dataset_import_job)
         """
 
@@ -267,7 +268,7 @@ class ForecastServiceClient(BaseClient):
         """
         Deletes a forecast created using the  CreateForecast operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.delete_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.delete_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_forecast)
         """
 
@@ -276,7 +277,7 @@ class ForecastServiceClient(BaseClient):
         Deletes a forecast export job created using the  CreateForecastExportJob
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.delete_forecast_export_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.delete_forecast_export_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_forecast_export_job)
         """
 
@@ -284,7 +285,7 @@ class ForecastServiceClient(BaseClient):
         """
         Deletes a predictor created using the  CreatePredictor operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.delete_predictor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.delete_predictor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_predictor)
         """
 
@@ -292,7 +293,7 @@ class ForecastServiceClient(BaseClient):
         """
         Deletes a predictor backtest export job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.delete_predictor_backtest_export_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.delete_predictor_backtest_export_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_predictor_backtest_export_job)
         """
 
@@ -300,7 +301,7 @@ class ForecastServiceClient(BaseClient):
         """
         Deletes an entire resource tree.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.delete_resource_tree)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.delete_resource_tree)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_resource_tree)
         """
 
@@ -308,7 +309,7 @@ class ForecastServiceClient(BaseClient):
         """
         Describes an Amazon Forecast dataset created using the  CreateDataset operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.describe_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.describe_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#describe_dataset)
         """
 
@@ -318,7 +319,7 @@ class ForecastServiceClient(BaseClient):
         """
         Describes a dataset group created using the  CreateDatasetGroup operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.describe_dataset_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.describe_dataset_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#describe_dataset_group)
         """
 
@@ -329,7 +330,7 @@ class ForecastServiceClient(BaseClient):
         Describes a dataset import job created using the  CreateDatasetImportJob
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.describe_dataset_import_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.describe_dataset_import_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#describe_dataset_import_job)
         """
 
@@ -337,7 +338,7 @@ class ForecastServiceClient(BaseClient):
         """
         Describes a forecast created using the  CreateForecast operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.describe_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.describe_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#describe_forecast)
         """
 
@@ -348,7 +349,7 @@ class ForecastServiceClient(BaseClient):
         Describes a forecast export job created using the  CreateForecastExportJob
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.describe_forecast_export_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.describe_forecast_export_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#describe_forecast_export_job)
         """
 
@@ -356,7 +357,7 @@ class ForecastServiceClient(BaseClient):
         """
         Describes a predictor created using the  CreatePredictor operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.describe_predictor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.describe_predictor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#describe_predictor)
         """
 
@@ -367,21 +368,21 @@ class ForecastServiceClient(BaseClient):
         Describes a predictor backtest export job created using the
         CreatePredictorBacktestExportJob operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.describe_predictor_backtest_export_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.describe_predictor_backtest_export_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#describe_predictor_backtest_export_job)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#generate_presigned_url)
         """
 
@@ -390,101 +391,101 @@ class ForecastServiceClient(BaseClient):
         Provides metrics on the accuracy of the models that were trained by the
         CreatePredictor operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.get_accuracy_metrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.get_accuracy_metrics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#get_accuracy_metrics)
         """
 
     def list_dataset_groups(
-        self, *, NextToken: str = None, MaxResults: int = None
+        self, *, NextToken: str = ..., MaxResults: int = ...
     ) -> ListDatasetGroupsResponseTypeDef:
         """
         Returns a list of dataset groups created using the  CreateDatasetGroup
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.list_dataset_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.list_dataset_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_dataset_groups)
         """
 
     def list_dataset_import_jobs(
         self,
         *,
-        NextToken: str = None,
-        MaxResults: int = None,
-        Filters: List["FilterTypeDef"] = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        Filters: Sequence["FilterTypeDef"] = ...
     ) -> ListDatasetImportJobsResponseTypeDef:
         """
         Returns a list of dataset import jobs created using the  CreateDatasetImportJob
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.list_dataset_import_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.list_dataset_import_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_dataset_import_jobs)
         """
 
     def list_datasets(
-        self, *, NextToken: str = None, MaxResults: int = None
+        self, *, NextToken: str = ..., MaxResults: int = ...
     ) -> ListDatasetsResponseTypeDef:
         """
         Returns a list of datasets created using the  CreateDataset operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.list_datasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.list_datasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_datasets)
         """
 
     def list_forecast_export_jobs(
         self,
         *,
-        NextToken: str = None,
-        MaxResults: int = None,
-        Filters: List["FilterTypeDef"] = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        Filters: Sequence["FilterTypeDef"] = ...
     ) -> ListForecastExportJobsResponseTypeDef:
         """
         Returns a list of forecast export jobs created using the
         CreateForecastExportJob operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.list_forecast_export_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.list_forecast_export_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_forecast_export_jobs)
         """
 
     def list_forecasts(
         self,
         *,
-        NextToken: str = None,
-        MaxResults: int = None,
-        Filters: List["FilterTypeDef"] = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        Filters: Sequence["FilterTypeDef"] = ...
     ) -> ListForecastsResponseTypeDef:
         """
         Returns a list of forecasts created using the  CreateForecast operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.list_forecasts)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.list_forecasts)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_forecasts)
         """
 
     def list_predictor_backtest_export_jobs(
         self,
         *,
-        NextToken: str = None,
-        MaxResults: int = None,
-        Filters: List["FilterTypeDef"] = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        Filters: Sequence["FilterTypeDef"] = ...
     ) -> ListPredictorBacktestExportJobsResponseTypeDef:
         """
         Returns a list of predictor backtest export jobs created using the
         CreatePredictorBacktestExportJob operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.list_predictor_backtest_export_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.list_predictor_backtest_export_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_predictor_backtest_export_jobs)
         """
 
     def list_predictors(
         self,
         *,
-        NextToken: str = None,
-        MaxResults: int = None,
-        Filters: List["FilterTypeDef"] = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        Filters: Sequence["FilterTypeDef"] = ...
     ) -> ListPredictorsResponseTypeDef:
         """
         Returns a list of predictors created using the  CreatePredictor operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.list_predictors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.list_predictors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_predictors)
         """
 
@@ -492,7 +493,7 @@ class ForecastServiceClient(BaseClient):
         """
         Lists the tags for an Amazon Forecast resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_tags_for_resource)
         """
 
@@ -500,33 +501,33 @@ class ForecastServiceClient(BaseClient):
         """
         Stops a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.stop_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.stop_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#stop_resource)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceArn: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
         """
         Associates the specified tags to a resource with the specified `resourceArn`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, ResourceArn: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Deletes the specified tags from a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#untag_resource)
         """
 
     def update_dataset_group(
-        self, *, DatasetGroupArn: str, DatasetArns: List[str]
+        self, *, DatasetGroupArn: str, DatasetArns: Sequence[str]
     ) -> Dict[str, Any]:
         """
         Replaces the datasets in a dataset group with the specified datasets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Client.update_dataset_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Client.update_dataset_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#update_dataset_group)
         """
 
@@ -535,7 +536,7 @@ class ForecastServiceClient(BaseClient):
         self, operation_name: Literal["list_dataset_groups"]
     ) -> ListDatasetGroupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listdatasetgroupspaginator)
         """
 
@@ -544,14 +545,14 @@ class ForecastServiceClient(BaseClient):
         self, operation_name: Literal["list_dataset_import_jobs"]
     ) -> ListDatasetImportJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listdatasetimportjobspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datasets"]) -> ListDatasetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Paginator.ListDatasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Paginator.ListDatasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listdatasetspaginator)
         """
 
@@ -560,14 +561,14 @@ class ForecastServiceClient(BaseClient):
         self, operation_name: Literal["list_forecast_export_jobs"]
     ) -> ListForecastExportJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listforecastexportjobspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_forecasts"]) -> ListForecastsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Paginator.ListForecasts)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Paginator.ListForecasts)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listforecastspaginator)
         """
 
@@ -576,13 +577,13 @@ class ForecastServiceClient(BaseClient):
         self, operation_name: Literal["list_predictor_backtest_export_jobs"]
     ) -> ListPredictorBacktestExportJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Paginator.ListPredictorBacktestExportJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Paginator.ListPredictorBacktestExportJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listpredictorbacktestexportjobspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_predictors"]) -> ListPredictorsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/forecast.html#ForecastService.Paginator.ListPredictors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecast.html#ForecastService.Paginator.ListPredictors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listpredictorspaginator)
         """
